@@ -23,7 +23,7 @@ rules over each domain."""
 
 import math, numpy
 
-def eval_jacobi(a,b,n,x):
+def eval_jacobi(a, b, n, x):
     """Evaluates the nth jacobi polynomial with weight parameters a,b at a
     point x. Recurrence relations implemented from the pseudocode
     given in Karniadakis and Sherwin, Appendix B"""
@@ -37,7 +37,7 @@ def eval_jacobi(a,b,n,x):
         pn2 = 1.0
         pn1 = 0.5 * ( a - b + ( apb + 2.0 ) * x )
         p = 0
-        for k in range(2,n+1):
+        for k in range(2, n+1):
             a1 = 2.0 * k * ( k + apb ) * ( 2.0 * k + apb - 2.0 )
             a2 = ( 2.0 * k + apb - 1.0 ) * ( a * a - b * b )
             a3 = ( 2.0 * k + apb - 2.0 )  \
@@ -53,16 +53,16 @@ def eval_jacobi(a,b,n,x):
             pn1 = p
         return p
 
-def eval_jacobi_batch(a,b,n,xs):
+def eval_jacobi_batch(a, b, n, xs):
     """Evaluates all jacobi polynomials with weights a,b
     up to degree n.  xs is a numpy.array of points.
     Returns a two-dimensional array of points, where the
     rows correspond to the Jacobi polynomials and the
     columns correspond to the points."""
-    result = numpy.zeros( (n+1,len(xs)),xs.dtype )
+    result = numpy.zeros((n+1, len(xs)), xs.dtype)
     # hack to make sure AD type is propogated through
     for ii in range(result.shape[1]):
-        result[0,ii] = 1.0 + xs[ii,0] - xs[ii,0]
+        result[0, ii] = 1.0 + xs[ii, 0] - xs[ii, 0]
 
     xsnew = xs.reshape((-1,))
 
@@ -70,7 +70,7 @@ def eval_jacobi_batch(a,b,n,xs):
         result[1,:] = 0.5 * ( a - b + ( a + b + 2.0 ) * xsnew )
     
         apb = a + b
-        for k in range(2,n+1):
+        for k in range(2, n+1):
             a1 = 2.0 * k * ( k + apb ) * ( 2.0 * k + apb - 2.0 )
             a2 = ( 2.0 * k + apb - 1.0 ) * ( a * a - b * b )
             a3 = ( 2.0 * k + apb - 2.0 )  \
@@ -85,26 +85,26 @@ def eval_jacobi_batch(a,b,n,xs):
                 - a4 * result[k-2,:]
     return result
 
-def eval_jacobi_deriv(a,b,n,x):
+def eval_jacobi_deriv(a, b, n, x):
     """Evaluates the first derivative of P_{n}^{a,b} at a point x."""
     if n == 0:
         return 0.0
     else:
-        return 0.5 * ( a + b + n + 1 ) * eval_jacobi(a+1,b+1,n-1,x)
+        return 0.5 * ( a + b + n + 1 ) * eval_jacobi(a+1, b+1, n-1, x)
 
-def eval_jacobi_deriv_batch(a,b,n,xs):
+def eval_jacobi_deriv_batch(a, b, n, xs):
     """Evaluates the first derivatives of all jacobi polynomials with
     weights a,b up to degree n.  xs is a numpy.array of points.
     Returns a two-dimensional array of points, where the
     rows correspond to the Jacobi polynomials and the
     columns correspond to the points."""
-    results = numpy.zeros( (n+1,len(xs)), "d" )
+    results = numpy.zeros( (n+1, len(xs)), "d" )
     if n == 0:
         return results
     else:
-        results[1:,:] = eval_jacobi_batch(a+1,b+1,n-1,xs)
-    for j in range(1,n+1):
-        results[j,:] *= 0.5*(a+b+j+1)
+        results[1:,:] = eval_jacobi_batch(a+1, b+1, n-1, xs)
+    for j in range(1, n+1):
+        results[j,:] *= (a+b+j+1)
     return results
 
 
